@@ -223,7 +223,7 @@ bool TransportManager::showTransportCreationDialog(QWidget *parent, ShowConditio
         const int response = KMessageBox::warningContinueCancel(parent,
                                                                 i18n("You must create an outgoing account before sending."),
                                                                 i18n("Create Account Now?"),
-                                                                KGuiItem(i18n("Create Account Now")),
+                                                                KGuiItem(i18nc("@action:button", "Create Account Now")),
                                                                 KStandardGuiItem::cancel());
         if (response != KMessageBox::Continue) {
             return false;
@@ -613,8 +613,8 @@ void TransportManagerPrivate::migrateToWallet()
                                                           "Do you want to migrate your passwords to KWallet?"),
                                                      names,
                                                      i18n("Question"),
-                                                     KGuiItem(i18n("Migrate")),
-                                                     KGuiItem(i18n("Keep")),
+                                                     KGuiItem(i18nc("@action:button", "Migrate")),
+                                                     KGuiItem(i18nc("@action:button", "Keep")),
                                                      QStringLiteral("WalletMigrate"));
     if (result != KMessageBox::ButtonCode::PrimaryAction) {
         return;
